==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/PolarScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarBaseDescriptionMetadata } from "./PolarBaseDescriptionMetadata";
import { PolarScatterSeriesDescription } from "./PolarScatterSeriesDescription";
/**
 * @hidden
 */
var PolarScatterSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PolarScatterSeriesDescriptionMetadata, _super);
    function PolarScatterSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarScatterSeriesDescriptionMetadata.b = function (a) {
        if (PolarScatterSeriesDescriptionMetadata.a == null) {
            PolarScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarScatterSeriesDescriptionMetadata.c(PolarScatterSeriesDescriptionMetadata.a);
        }
        if (a.j(PolarScatterSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(PolarScatterSeriesDescriptionMetadata.a);
    };
    PolarScatterSeriesDescriptionMetadata.c = function (a) {
        PolarBaseDescriptionMetadata.c(a);
    };
    PolarScatterSeriesDescriptionMetadata.d = function (a) {
        PolarScatterSeriesDescriptionMetadata.b(a);
        a.aa("PolarScatterSeries", function () { return new PolarScatterSeriesDescription(); });
        a.z("PolarScatterSeries", PolarScatterSeriesDescriptionMetadata.a);
    };
    PolarScatterSeriesDescriptionMetadata.$t = markType(PolarScatterSeriesDescriptionMetadata, 'PolarScatterSeriesDescriptionMetadata');
    PolarScatterSeriesDescriptionMetadata.a = null;
    return PolarScatterSeriesDescriptionMetadata;
}(Base));
export { PolarScatterSeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/PolarScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarBaseDescriptionMetadata } from "./PolarBaseDescriptionMetadata";
import { PolarScatterSeriesDescription } from "./PolarScatterSeriesDescription";
/**
 * @hidden
 */
var PolarScatterSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PolarScatterSeriesDescriptionMetadata, _super);
    function PolarScatterSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarScatterSeriesDescriptionMetadata.b = function (a) {
        if (PolarScatterSeriesDescriptionMetadata.a == null) {
            PolarScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarScatterSeriesDescriptionMetadata.c(PolarScatterSeriesDescriptionMetadata.a);
        }
        if (a.k(PolarScatterSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(PolarScatterSeriesDescriptionMetadata.a);
    };
    PolarScatterSeriesDescriptionMetadata.c = function (a) {
        PolarBaseDescriptionMetadata.c(a);
    };
    PolarScatterSeriesDescriptionMetadata.d = function (a) {
        PolarScatterSeriesDescriptionMetadata.b(a);
        a.ac("PolarScatterSeries", function () { return new PolarScatterSeriesDescription(); });
        a.ab("PolarScatterSeries", PolarScatterSeriesDescriptionMetadata.a);
    };
    PolarScatterSeriesDescriptionMetadata.$t = markType(PolarScatterSeriesDescriptionMetadata, 'PolarScatterSeriesDescriptionMetadata');
    PolarScatterSeriesDescriptionMetadata.a = null;
    return PolarScatterSeriesDescriptionMetadata;
}(Base));
export { PolarScatterSeriesDescriptionMetadata };
